@@ -24,12 +24,16 @@ options:
     name:
         description:
             - Only show results for a specific Public IP.
+        type: str
     resource_group:
         description:
             - Limit results by resource group. Required when using name parameter.
+        type: str
     tags:
         description:
             - Limit results by providing a list of tags. Format tags as 'key' or 'key:value'.
+        type: list
+        elements: str
 
 extends_documentation_fragment:
     - azure.azcollection.azure
@@ -40,14 +44,16 @@ author:
 '''
 
 EXAMPLES = '''
-    - name: Get facts for one Public IP
-      azure_rm_publicipaddress_info:
-        resource_group: myResourceGroup
-        name: publicip001
+- name: Get facts for one Public IP
+  azure_rm_publicipaddress_info:
+    resource_group: myResourceGroup
+    name: publicip001
 
-    - name: Get facts for all Public IPs within a resource groups
-      azure_rm_publicipaddress_info:
-        resource_group: myResourceGroup
+- name: Get facts for all Public IPs within a resource groups
+  azure_rm_publicipaddress_info:
+    resource_group: myResourceGroup
+    tags:
+      - key:value
 '''
 
 RETURN = '''
@@ -133,7 +139,7 @@ publicipaddresses:
             sample: {
                     "domain_name_label": "ansible-b57dc95985712e45eb8b9c2e",
                     "fqdn": "ansible-b57dc95985712e45eb8b9c2e.eastus.cloudapp.azure.com",
-                    "reverse_fqdn": null
+                    "reverse_fqdn": "ansible-b57dc95985712e45eb8b9c2f.eastus.cloudapp.azure.com"
                     }
         ip_tags:
             description:
@@ -176,7 +182,13 @@ publicipaddresses:
                 - The public IP address SKU.
             returned: always
             type: str
-            sample: Basic
+            sample: Standard
+        zones:
+            description:
+                - A list of availability zones denoting the IP allocated for the resource needs to come from.
+            returned: always
+            type: list
+            sample: ['1', '2']
 '''
 try:
     from azure.core.exceptions import ResourceNotFoundError
@@ -196,7 +208,7 @@ class AzureRMPublicIPInfo(AzureRMModuleBase):
         self.module_arg_spec = dict(
             name=dict(type='str'),
             resource_group=dict(type='str'),
-            tags=dict(type='list')
+            tags=dict(type='list', elements='str')
         )
 
         self.results = dict(
@@ -272,7 +284,8 @@ class AzureRMPublicIPInfo(AzureRMModuleBase):
             idle_timeout=pip.idle_timeout_in_minutes,
             provisioning_state=pip.provisioning_state,
             etag=pip.etag,
-            sku=pip.sku.name
+            sku=pip.sku.name,
+            zones=pip.zones
         )
         if pip.dns_settings:
             result['dns_settings']['domain_name_label'] = pip.dns_settings.domain_name_label
