@@ -101,9 +101,10 @@ options:
             password:
                 type: raw
                 description: (list) Local certificate password.
-            private-key:
+            private_key:
+                aliases: ['private-key']
                 type: raw
-                description: (list) Deprecated, please rename it to private_key. Local certificate private-key.
+                description: (list) Local certificate private-key.
 '''
 
 EXAMPLES = '''
@@ -124,12 +125,12 @@ EXAMPLES = '''
         # rc_failed: [-2, -3, ...]
         state: present # <value in [present, absent]>
         system_certificate_local:
-          certificate: <list or string>
-          comment: <string>
-          csr: <list or string>
-          name: <string>
-          password: <list or string>
-          private_key: <list or string>
+          name: "your value" # Required variable, string
+          # certificate: <list or string>
+          # comment: <string>
+          # csr: <list or string>
+          # password: <list or string>
+          # private_key: <list or string>
 '''
 
 RETURN = '''
@@ -173,21 +174,14 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/cli/global/system/certificate/local'
     ]
-
-    perobject_jrpc_urls = [
-        '/cli/global/system/certificate/local/{local}'
-    ]
-
     url_params = []
     module_primary_key = 'name'
     module_arg_spec = {
@@ -202,7 +196,6 @@ def main():
                 'password': {'no_log': True, 'type': 'raw'},
                 'private-key': {'no_log': True, 'type': 'raw'}
             }
-
         }
     }
 
@@ -211,17 +204,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'system_certificate_local'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
