@@ -8,16 +8,20 @@ from __future__ import (absolute_import, division, print_function)
 __metaclass__ = type
 
 import json
+import sys
 import pytest
 
 from ansible.module_utils import basic
 from ansible.module_utils._text import to_bytes
 from ansible_collections.netapp.cloudmanager.tests.unit.compat import unittest
-from ansible_collections.netapp.cloudmanager.tests.unit.compat.mock import patch, Mock
-
+from ansible_collections.netapp.cloudmanager.tests.unit.compat.mock import patch
+import ansible_collections.netapp.cloudmanager.plugins.module_utils.netapp as netapp_utils
 from ansible_collections.netapp.cloudmanager.plugins.modules.na_cloudmanager_cvo_azure \
     import NetAppCloudManagerCVOAZURE as my_module
 
+if not netapp_utils.HAS_REQUESTS and sys.version_info < (3, 5):
+    pytestmark = pytest.mark.skip('skipping as missing required imports on 2.6 and 2.7')
+
 
 def set_module_args(args):
     '''prepare arguments so that they will be picked up during module creation'''
@@ -341,6 +345,7 @@ class TestMyModule(unittest.TestCase):
         assert exc.value.args[0]['changed']
 
     @patch('ansible_collections.netapp.cloudmanager.plugins.module_utils.netapp.CloudManagerRestAPI.get_token')
+    @patch('ansible_collections.netapp.cloudmanager.plugins.module_utils.netapp_module.NetAppModule.update_writing_speed_state')
     @patch('ansible_collections.netapp.cloudmanager.plugins.module_utils.netapp_module.NetAppModule.update_instance_license_type')
     @patch('ansible_collections.netapp.cloudmanager.plugins.module_utils.netapp_module.NetAppModule.update_tier_level')
     @patch('ansible_collections.netapp.cloudmanager.plugins.module_utils.netapp_module.NetAppModule.update_cvo_tags')
@@ -350,7 +355,7 @@ class TestMyModule(unittest.TestCase):
     @patch('ansible_collections.netapp.cloudmanager.plugins.module_utils.netapp_module.NetAppModule.get_working_environment_property')
     @patch('ansible_collections.netapp.cloudmanager.plugins.module_utils.netapp_module.NetAppModule.get_working_environment_details_by_name')
     def test_change_cloudmanager_cvo_azure(self, get_cvo, get_property, get_details, upgrade_ontap_image, update_svm_password, update_cvo_tags,
-                                           update_tier_level, update_instance_license_type, get_token):
+                                           update_tier_level, update_instance_license_type, update_writing_speed_state, get_token):
         data = self.set_default_args_pass_check()
         data['svm_password'] = 'newpassword'
         data['update_svm_password'] = True
@@ -359,7 +364,7 @@ class TestMyModule(unittest.TestCase):
         data['instance_type'] = 'Standard_DS13_v2'
         set_module_args(data)
 
-        modify = ['svm_password', 'azure_tag', 'tier_level', 'ontap_version', 'instance_type']
+        modify = ['svm_password', 'azure_tag', 'tier_level', 'ontap_version', 'instance_type', 'license_type']
 
         my_cvo = {
             'name': 'TestA',
@@ -372,6 +377,7 @@ class TestMyModule(unittest.TestCase):
 
         cvo_property = {'name': 'TestA',
                         'publicId': 'test',
+                        'status': {'status': 'ON'},
                         'ontapClusterProperties': {
                             'capacityTierInfo': {'tierLevel': 'normal'},
                             'licensePackageName': 'Professional',
@@ -406,7 +412,7 @@ class TestMyModule(unittest.TestCase):
                        'name': 'TestA',
                        'ontapClusterProperties': None,
                        'publicId': 'test',
-                       'status': None,
+                       'status': {'status': 'ON'},
                        'userTags': {'DeployedByOccm': 'true', 'key1': 'value1'},
                        'workingEnvironmentType': 'VSA'}
         get_details.return_value = cvo_details, None
@@ -422,6 +428,8 @@ class TestMyModule(unittest.TestCase):
                 update_tier_level.return_value = True, None
             elif item == 'ontap_version':
                 upgrade_ontap_image.return_value = True, None
+            elif item == 'writing_speed_state':
+                update_writing_speed_state.return_value = True, None
             elif item == 'instance_type':
                 update_instance_license_type.return_value = True, None
 
